@@ -3,8 +3,8 @@
 
 namespace Icinga\Controllers;
 
-use Icinga\Application\Icinga;
 use Icinga\Web\Controller\ActionController;
+use Icinga\Web\Menu;
 
 /**
  * Create complex layout parts
@@ -18,7 +18,7 @@ class LayoutController extends ActionController
     {
         $this->setAutorefreshInterval(15);
         $this->_helper->layout()->disableLayout();
-        $this->view->menuRenderer = Icinga::app()->getMenu()->getRenderer();
+        $this->view->menuRenderer = (new Menu())->getRenderer();
     }
 
     public function announcementsAction()
