@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2014 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Data\Filter;
 
@@ -7,6 +7,10 @@ class FilterEqual extends FilterExpression
 {
     public function matches($row)
     {
+        if (! isset($row->{$this->column})) {
+            return false;
+        }
+
         return (string) $row->{$this->column} === (string) $this->expression;
     }
 }
