@@ -89,7 +89,7 @@ class FileReader implements Selectable, Countable
      *
      * @return int
      */
-    public function count()
+    public function count(): int
     {
         if ($this->count === null) {
             $this->count = iterator_count($this->iterate());
@@ -129,10 +129,10 @@ class FileReader implements Selectable, Countable
         }
         $lines = array();
         if ($query->sortDesc()) {
-            $count = $this->count($query);
+            $count = $this->count();
             if ($count <= $skip) {
                 return $lines;
-            } else if ($count < ($skip + $read)) {
+            } elseif ($count < ($skip + $read)) {
                 $read = $count - $skip;
                 $skip = 0;
             } else {
