@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2015 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Repository;
 
@@ -64,6 +64,29 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
         $this->repository = $repository;
     }
 
+    /**
+     * Clone all state relevant properties of this query
+     */
+    public function __clone()
+    {
+        if ($this->query !== null) {
+            $this->query = clone $this->query;
+        }
+        if ($this->iterator !== null) {
+            $this->iterator = clone $this->iterator;
+        }
+    }
+
+    /**
+     * Return a string representation of this query
+     *
+     * @return  string
+     */
+    public function __toString()
+    {
+        return (string) $this->query;
+    }
+
     /**
      * Return the real query being used
      *
@@ -86,7 +109,7 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
      */
     public function from($target, array $columns = null)
     {
-        $this->query = $this->repository->getDataSource()->select();
+        $this->query = $this->repository->getDataSource($target)->select();
         $this->query->from($this->repository->requireTable($target, $this));
         $this->query->columns($this->prepareQueryColumns($target, $columns));
         $this->target = $target;
@@ -181,7 +204,7 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
      */
     public function getFilterColumns()
     {
-        return $this->repository->getFilterColumns();
+        return $this->repository->getFilterColumns($this->target);
     }
 
     /**
@@ -191,7 +214,7 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
      */
     public function getSearchColumns()
     {
-        return $this->repository->getSearchColumns();
+        return $this->repository->getSearchColumns($this->target);
     }
 
     /**
@@ -271,7 +294,7 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
      */
     public function getSortRules()
     {
-        return $this->repository->getSortRules();
+        return $this->repository->getSortRules($this->target);
     }
 
     /**
@@ -321,7 +344,9 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
             }
         }
 
-        $baseDirection = strtoupper($sortColumns['order']) === static::SORT_DESC ? static::SORT_DESC : static::SORT_ASC;
+        $baseDirection = isset($sortColumns['order']) && strtoupper($sortColumns['order']) === static::SORT_DESC
+            ? static::SORT_DESC
+            : static::SORT_ASC;
 
         foreach ($sortColumns['columns'] as $column) {
             list($column, $specificDirection) = $this->splitOrder($column);
@@ -400,11 +425,14 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
      * Enabling this causes the current query limit to be increased by one. The potential extra row being yielded will
      * be removed from the result set. Note that this only applies when fetching multiple results of limited queries.
      *
+     * @param   bool    $state
+     *
      * @return  $this
      */
     public function peekAhead($state = true)
     {
-        return $this->query->peekAhead($state);
+        $this->query->peekAhead($state);
+        return $this;
     }
 
     /**
@@ -580,8 +608,7 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
                 $aliases[1] !== 1 ? $this->getNativeAlias($aliases[1]) : $columns[1]
             );
 
-            if (
-                $this->repository->providesValueConversion($this->target, $colOne)
+            if ($this->repository->providesValueConversion($this->target, $colOne)
                 || $this->repository->providesValueConversion($this->target, $colTwo)
             ) {
                 $newResults = array();
@@ -665,7 +692,7 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
      *
      * @return  int
      */
-    public function count()
+    public function count(): int
     {
         return $this->query->count();
     }
@@ -683,7 +710,7 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
     /**
      * Start or rewind the iteration
      */
-    public function rewind()
+    public function rewind(): void
     {
         if ($this->iterator === null) {
             if (! $this->hasOrder()) {
@@ -693,7 +720,7 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
             if ($this->query instanceof Traversable) {
                 $iterator = $this->query;
             } else {
-                $iterator = $this->repository->getDataSource()->query($this->query);
+                $iterator = $this->repository->getDataSource($this->target)->query($this->query);
             }
 
             if ($iterator instanceof IteratorAggregate) {
@@ -710,8 +737,9 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
     /**
      * Fetch and return the current row of this query's result
      *
-     * @return  object
+     * @return  mixed
      */
+    #[\ReturnTypeWillChange]
     public function current()
     {
         $row = $this->iterator->current();
@@ -738,7 +766,7 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
      *
      * @return  bool
      */
-    public function valid()
+    public function valid(): bool
     {
         if (! $this->iterator->valid()) {
             Benchmark::measure('Query result iteration finished');
@@ -753,6 +781,7 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
      *
      * @return  mixed
      */
+    #[\ReturnTypeWillChange]
     public function key()
     {
         return $this->iterator->key();
@@ -761,7 +790,7 @@ class RepositoryQuery implements QueryInterface, SortRules, FilterColumns, Itera
     /**
      * Advance to the next row of this query's result
      */
-    public function next()
+    public function next(): void
     {
         $this->iterator->next();
     }
