@@ -3,6 +3,7 @@
 
 namespace Icinga\Module\Monitoring\Backend\Ido\Query;
 
+use Icinga\Data\Filter\FilterExpression;
 use Zend_Db_Expr;
 use Zend_Db_Select;
 use Icinga\Data\Filter\Filter;
@@ -17,6 +18,7 @@ class CommentdeletionhistoryQuery extends IdoQuery
      */
     protected $columnMap = array(
         'commenthistory' => array(
+            'id'          => 'cdh.id',
             'object_type' => 'cdh.object_type'
         ),
         'history' => array(
@@ -164,4 +166,14 @@ class CommentdeletionhistoryQuery extends IdoQuery
         }
         return $this;
     }
+
+    public function whereEx(FilterExpression $ex)
+    {
+        $this->requireColumn($ex->getColumn());
+        foreach ($this->subQueries as $sub) {
+            $sub->whereEx($ex);
+        }
+
+        return $this;
+    }
 }
