@@ -40,7 +40,7 @@
         var $a = $(event.currentTarget);
         var url = $a.attr('href');
         var $modal = _this.$ghost.clone();
-        var $urlTarget = _this.icinga.loader.getLinkTargetFor($a, false);
+        var $redirectTarget = $a.closest('.container');
 
         _this.modalOpener = event.currentTarget;
 
@@ -50,8 +50,8 @@
         // Add showCompact, we don't want controls in a modal
         url = _this.icinga.utils.addUrlFlag(url, 'showCompact');
 
-        // Set the toggle's base target on the modal to use it as redirect target
-        $modal.data('redirectTarget', $urlTarget);
+        // Set the toggle's container to use it as redirect target
+        $modal.data('redirectTarget', $redirectTarget);
 
         // Final preparations, the id is required so that it's not `display:none` anymore
         $modal.attr('id', 'modal');
@@ -68,7 +68,7 @@
             if (req.status >= 500) {
                 // Yes, that's done twice (by us and by the base fail handler),
                 // but `renderContentToContainer` does too many useful things..
-                _this.icinga.loader.renderContentToContainer(req.responseText, $urlTarget, req.action);
+                _this.icinga.loader.renderContentToContainer(req.responseText, $redirectTarget, req.action);
             } else if (req.status > 0) {
                 var msg = $(req.responseText).find('.error-message').text();
                 if (msg && msg !== errorThrown) {
@@ -91,29 +91,55 @@
      * @param $autoSubmittedBy {jQuery} The element triggering the auto submit, if any
      * @returns {boolean}
      */
-    Modal.prototype.onFormSubmit = function(event, $autoSubmittedBy) {
-        var _this = event.data.self;
-        var $form = $(event.currentTarget).closest('form');
-        var $modal = $form.closest('#modal');
+    Modal.prototype.onFormSubmit = function(event) {
+        const _this = event.data.self;
+        const $form = $(event.currentTarget).closest('form');
+        const $modal = $form.closest('#modal');
 
-        var $button;
-        var $rememberedSubmittButton = $form.data('submitButton');
-        if (typeof $rememberedSubmittButton != 'undefined') {
-            if ($form.has($rememberedSubmittButton)) {
-                $button = $rememberedSubmittButton;
+        let $button;
+        if (typeof event.originalEvent !== 'undefined'
+            && typeof event.originalEvent.submitter !== 'undefined'
+            && event.originalEvent.submitter !== null) {
+            $button = $(event.originalEvent.submitter);
+        }
+
+        // Safari fallback only
+        const $rememberedSubmitButton = $form.data('submitButton');
+        if (typeof $rememberedSubmitButton !== 'undefined') {
+            if (typeof $button === 'undefined' && $form.has($rememberedSubmitButton)) {
+                $button = $rememberedSubmitButton;
             }
+
             $form.removeData('submitButton');
         }
 
-        var req = _this.icinga.loader.submitForm($form, $autoSubmittedBy, $button);
+        let $autoSubmittedBy;
+        if (typeof event.detail !== 'undefined' && "submittedBy" in event.detail) {
+            $autoSubmittedBy = $(event.detail.submittedBy);
+        }
+
+        // Prevent our other JS from running
+        $modal[0].dataset.noIcingaAjax = '';
+
+        const req = _this.icinga.loader.submitForm($form, $autoSubmittedBy, $button);
         req.addToHistory = false;
-        req.$redirectTarget = $modal.data('redirectTarget');
         req.done(function (data, textStatus, req) {
+            const title = req.getResponseHeader('X-Icinga-Title');
+            if (!! title) {
+                _this.setTitle($modal, decodeURIComponent(title).replace(/\s::\s.*/, ''));
+            }
+
             if (req.getResponseHeader('X-Icinga-Redirect')) {
                 _this.hide($modal);
             }
+        }).always(function () {
+            delete $modal[0].dataset.noIcingaAjax;
         });
 
+        if (! ('baseTarget' in $form[0].dataset)) {
+            req.$redirectTarget = $modal.data('redirectTarget');
+        }
+
         if (typeof $autoSubmittedBy === 'undefined') {
             // otherwise the form is submitted several times by clicking the "Submit" button several times
             $form.find('input[type=submit],button[type=submit],button:not([type])').prop('disabled', true);
@@ -131,7 +157,17 @@
      * @returns {boolean}
      */
     Modal.prototype.onFormAutoSubmit = function(event) {
-        return event.data.self.onFormSubmit(event, $(event.currentTarget));
+        let form = event.currentTarget.form;
+        let modal = form.closest('#modal');
+
+        // Prevent our other JS from running
+        modal.dataset.noIcingaAjax = '';
+
+        form.dispatchEvent(new CustomEvent('submit', {
+            cancelable: true,
+            bubbles: true,
+            detail: { submittedBy: event.currentTarget }
+        }));
     };
 
     /**
@@ -168,7 +204,10 @@
         var _this = event.data.self;
 
         if (! event.isDefaultPrevented() && event.key === 'Escape') {
-            _this.hide(_this.$layout.children('#modal'));
+            let $modal = _this.$layout.children('#modal');
+            if ($modal.length) {
+                _this.hide($modal);
+            }
         }
     };
 
